@@ -1,19 +1,20 @@
 <?php
+
 return array(
     'grabber' => array(
         '%.*%' => array(
             'body' => array(
                 '//img[@id="strip"]',
-                '//a/div[@id="nx"]/..'
+                '//a/div[@id="nx"]/..',
             ),
             'strip' => array(),
-            'test_url' => 'http://oglaf.com/slodging/'
-        )
+            'test_url' => 'http://oglaf.com/slodging/',
+        ),
     ),
     'filter' => array(
         '%.*%' => array(
-            '%alt="(.+)" title="(.+)" */>%' => "/><br/>$1<br/>$2<br/>",
+            '%alt="(.+)" title="(.+)" */>%' => '/><br/>$1<br/>$2<br/>',
             '%</a>%' => 'Next page</a>',
-        )
-    )
+        ),
+    ),
 );
