@@ -1,13 +1,14 @@
 <?php
+
 return array(
     'grabber' => array(
         '%.*%' => array(
             'test_url' => 'http://satwcomic.com/day-at-the-beach',
             'body' => array(
                 '//div[@class="container"]/center/a/img',
-                '//span[@itemprop="articleBody"]'
+                '//span[@itemprop="articleBody"]',
             ),
             'strip' => array(),
-        )
-    )
-);
\ No newline at end of file
+        ),
+    ),
+);
