@@ -1,8 +1,9 @@
 <?php
+
 return array(
     'filter' => array(
         '%.*%' => array(
-            '%(<img.+)(\.png"/>)%' => '$1$2$1after$2'
-        )
-    )
+            '%(<img.+)(\.png"/>)%' => '$1$2$1after$2',
+        ),
+    ),
 );
