@@ -1,13 +1,14 @@
 <?php
+
 return array(
     'grabber' => array(
         '%.*%' => array(
             'test_url' => 'http://stupidfox.net/134-sleepy-time',
             'body' => array(
                 '//div[@class="comicmid"]/center/a/img',
-                '//div[@class="stand_high"]'
+                '//div[@class="stand_high"]',
             ),
             'strip' => array(),
-        )
-    )
-);
\ No newline at end of file
+        ),
+    ),
+);
